# Generated by roxygen2: do not edit by hand

S3method(aggregation_parameters,mf_model)
S3method(as.forecast,mf_model_forecast)
S3method(autoplot,mf_model_forecast)
S3method(coef,mf_model)
S3method(confint,mf_model)
S3method(fitted,mf_model)
S3method(forecast,mf_model)
S3method(formula,mf_model)
S3method(indicators,mf_model)
S3method(model.frame,mf_model)
S3method(nobs,mf_model)
S3method(plot,mf_model)
S3method(plot,mf_model_forecast)
S3method(print,mf_model)
S3method(print,mf_model_forecast)
S3method(print,summary.mf_model)
S3method(residuals,mf_model)
S3method(summary,mf_model)
S3method(variable.names,mf_model)
S3method(vcov,mf_model)
S3method(weights,mf_model)
export(aggregation_parameters)
export(as.forecast)
export(autoplot)
export(bridge)
export(colors_bridgr)
export(forecast)
export(indicators)
export(mf_model)
export(scale_color_bridgr)
export(scale_fill_bridgr)
export(theme_bridgr)
importFrom(forecast,forecast)
importFrom(ggplot2,autoplot)
importFrom(lubridate,"%m+%")
importFrom(lubridate,"%m-%")
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(stats,model.frame)
importFrom(stats,nobs)
importFrom(stats,variable.names)
importFrom(stats,weights)
importFrom(utils,tail)
